@@ -1,5 +1,5 @@
 package MooX::PluginKit;
-$MooX::PluginKit::VERSION = '0.02';
+$MooX::PluginKit::VERSION = '0.03';
 # I don't do anything.
 
 1;
@@ -9,10 +9,37 @@ __END__
 
 MooX::PluginKit - A comprehensive plugin system.
 
+=head1 SYNOPSIS
+
+    package MyApp::Plugin::LogEngine;
+    use Moo::Role;
+    use MooX::PluginKit::Plugin;
+    plugin_applies_to 'MyApp::Engine';
+    before start => sub{ print "Starting app.\n" };
+    after stop => sub{ print "Stopped app.\n" };
+
+    package MyApp::Engine;
+    use Moo;
+    sub start { ... }
+    sub stop { ... }
+
+    package MyApp;
+    use Moo;
+    use MooX::PluginKit::Consumer;
+    has_pluggable_object engine => (
+        class   => 'MyApp::Engine',
+        default => sub{ {} },
+    );
+
+    my $app = MyApp->new(
+        plugins => ['LogEngine'],
+    );
+    $app->engine->start(); # Prints: Starting app.
+
 =head1 INTRODUCTION
 
 PluginKit provides a simple interface for creating plugins and
-consuming those plugins.
+consuming those plugins at run-time.
 
 PluginKit is comprised of two main pieces: the plugins, and the
 classes which consume the plugins.  A plugin is just a regular
@@ -38,87 +65,6 @@ Plugins may include other plugins.
 This means that you can make groups of plugins which apply to various
 classes in a hierarchy.
 
-=head1 IN THE REAL WORLD
-
-What fun would a fancy idea be if it had no real world applications!
-
-Here's some real-world plugins/things done-right and done-wrong and
-how PluginKit could play a role in them.
-
-NOTE: This section is purely the opinion of the author.  If you disagree
-or have better examples/wording/ideas, please let him know!
-
-=head2 Catalyst
-
-L<Catalyst> could benefit from this module.  Currently extending the
-context class, the request class, and the response class all require
-separate directives manually entered in by the end-user of Catalyst.
-Its really a lot of mess when a feature is implemented by, for example,
-both a request and response plugin.  If you forget one, the whole thing
-breaks.  Here's a fake example of how things currently look:
-
-    use Catalyst (
-        SomeContextPlugin
-    );
-    use CatalystX::RoleApplicator;
-    __PACKAGE__->apply_request_class_roles(
-        SomeRequestPlugin
-    );
-    __PACKAGE__->apply_response_class_roles(
-        SomeResponsePlugin
-    );
-    # Note, there is also apply_engine_class_roles, apply_dispatcher_class_roles
-    # and apply_stats_class_roles.
-
-Oh my!  Let's say we start off by using a PluginKit plugin's ability to
-declare which classes they belong to.  Then we could just do this:
-
-    use Catalyst (
-        SomeContextPlugin
-        SomeRequestPlugin
-        SomeResponsePlugin
-    );
-
-And then one step further if those three plugins, when used together, comprised
-a single feature then we could just:
-
-    use Catalyst (
-        SomePlugin
-    );
-
-If Catalyst used PluginKit then all the user would have to do is declare that
-they use the root plugin and the rest of the plugins would automatically find
-their way into the appropriate classes.
-
-=head2 Starch
-
-L<Starch> is the inspiration for this module.  It has a home-grown plugin
-system very similar, but inferior, to PluginKit.  Starch has complex plugins
-which alter the behavior of various systems (classes) within Starch.  For
-a simple example, L<Starch::Plugin::Trace> injects C<around()> modifiers
-within 3 different classes at object construction time.  And all a user need
-to do is:
-
-    my $starch = Starch->new( plugins=>['::Trace'] );
-
-Without a plugin system to hide away these complexities the user would have
-been exposed to implementation details and would leave gaping holes for
-humans to make errors.
-
-=head2 Test::WWW::Mechanize::PSGI
-
-Yay!  Fake a web server with L<Test::WWW::Mechanize::PSGI>!  Thats awesome.
-But, uh, what if you want the C<::PSGI> but don't need the C<Test::>.  What
-if you don't want the C<::Mechanize::> and want just C<LWP::UserAgent::PSGI>?
-Wouldn't it be nice if you could just do:
-
-    my $ua = LWP::UserAgent->new( plugins=>['::PSGI', '::Test'] );
-
-PluginKit would make this super simple to support.  Also there is a god awful
-number CPAN module subclasses and subclasses of those subclasses on
-CPAN.  Its a world of hurt with no flexibility.  It has made me cry a few
-times.
-
 =head1 CREATING PLUGINS
 
 =head2 Basics
@@ -128,9 +74,7 @@ The most minimal plugin is a L<Moo::Role>:
     package MyApp::Plugin::Foo;
     use Moo::Role;
 
-But if that is all you are doing then you're just using PluginKit as
-a tool to apply roles at run-time.  That's cool and all, but PluginKit
-can do so much more.
+This sort of plugin will apply to any class.
 
 =head2 Bundling
 
@@ -145,29 +89,15 @@ plugin name:
     plugin_includes '::Bar';
 
 C<plugin_includes> takes a list, so you may include multiple plugins.
-Gnarly, we can package together plugins!  Yes, you could get the
-same effect with a simple L<Moo/with>, but then you wouldn't get
-the contextual nature of PluginKit plugins as described next.
 
 =head2 Contextual
 
-Take everything you learned so far and throw this awesome bomb
-at it:
-
     plugin_applies_to 'MyApp::SomeClass';
 
-Did you hear the mic drop?  Maybe not, so let me explain it for ya.  You
-can create groups of plugins (even groups of groups of groups of plugins)
-and each plugin, at any level, can declare what kinds of classes it (and its
-included plugins) applies to.  This means you can tell your end-user "use
-plugin X" and behind the scenes they could potentially be using dozens of
-plugins applied dynamically to dozens of classes.  This makes something that is
-normally hard and complex for the end-user something that only the plugin
-author needs to deal with and can tightly control.
-
-Is it a good idea to write a dozen plugins and apply them to a dozen classes?
-Probably not!  Would it be fun to write a dozen plugins and dynamically apply
-them to a dozen classes at run time without the user's knowledge?  Heck ya!
+This declares that this plugins only applies to the specified class (or
+subclasses of it).  This is where PluginKit's power really shines as it
+allows plugin authors to transparently decide how and where plugins get
+applied and plugin users to not need to know the intricate details.
 
 Note that when you specify the C<plugin_applies_to> you can provide a package
 name, a regex, an array ref of method names (aka duck type), or a custom subroutine
@@ -184,11 +114,9 @@ to your library.
 =head2 Plugins Argument
 
 L<MooX::PluginKit::Consumer>, when C<use>d sets the subclass, applies a role,
-and exports some candy functions to make creating a plugin consuming class
-simple as pie.
+and exports some candy functions for building your plugin consuming class.
 
-To make your class accept a C<plugins> argument it goes something like this
-(well, actually, exactly like this):
+A class which accepts a C<plugins> argument looks like this:
 
     package MyApp;
     use Moo;
@@ -201,12 +129,8 @@ so:
 
 =head2 Object Attributes
 
-But, there is more!  Your objects often refer to other objects, right?  Those
-other objects shouldn't be left out of the plugin goodness, so open up your
-arms and hug them in!
-
-    has_pluggable_object foo => (
-        class => 'MyApp::Foo',
+    has_pluggable_object engine => (
+        class => 'MyApp::Enging',
     );
 
 C<has_pluggable_object> takes many of the same arguments as L<Moo/has>.  When setup like
@@ -214,20 +138,31 @@ above, rather than passing an object as the argument you'd pass a hashref which
 automatically coerced into an object with all relevant plugins applied.  If you'd like
 to default the object you can with something like this:
 
-    has_pluggable_object foo => (
-        class     => 'MyApp::Foo',
+    has_pluggable_object engine => (
+        class     => 'MyApp::Engine',
         default => sub{ {} },
     );
 
 See more at L<MooX::PluginKit::Consumer/has_pluggable_object>.
 
+=head2 Class Attributes
+
+    has_pluggable_class response_class => (
+        default => 'MyApp::Response',
+    );
+
+This is useful for when you want to dynamically create instances of a class which supports
+plugins.  The value of this attribute will be the composed class name with all plugins applied.
+
+See more at L<MooX::PluginKit::Consumer/has_pluggable_class>.
+
 =head2 Relative Plugin Namespace
 
 If your user specifies a plugin starting with C<::> that means the plugin is
 relative.  By default it will be relative to your consuming class name, so
 if your class is C<MyApp> and the user wants to apply the C<::Foo> plugin then
-that will resolve to the C<MyApp::Foo> plugin.  Unlike many things in life, you
-can change this:
+that will resolve to the C<MyApp::Foo> plugin.  This default behavior can be
+changed:
 
     plugin_namespace 'MyApp::Plugin';
 
@@ -238,9 +173,11 @@ See more at L<MooX::PluginKit::Consumer/plugin_namespace>.
 
 =head2 The Factory
 
-Alternatively you are welcome to use L<MooX::PluginKit::Factory> directly.  It is
-a more direct and lower level interface to popping out objects with plugins applied,
-so its considered a power-user tool.
+Behind the scenes there is a factory object which does all the heavy lifting of this
+library.  This factory can be accessed as the C<plugin_factory> attribute on
+consumer classes or an instance of the factory class may be created directly.
+
+See more at L<MooX::PluginKit::Factory>.
 
 =head1 TODO
 
