@@ -1,5 +1,5 @@
 package MooX::PluginKit::Consumer;
-$MooX::PluginKit::Consumer::VERSION = '0.02';
+$MooX::PluginKit::Consumer::VERSION = '0.03';
 =head1 NAME
 
 MooX::PluginKit::Consumer - Declare a class as a consumer of
@@ -39,7 +39,9 @@ be found at L<MooX::PluginKit/CONSUMING PLUGINS>.
 use MooX::PluginKit::Core;
 use MooX::PluginKit::ConsumerRole;
 use Types::Standard -types;
+use Types::Common::String -types;
 use Class::Method::Modifiers qw( install_modifier );
+use Module::Runtime qw( require_module );
 use Scalar::Util qw( blessed );
 use Carp qw( croak );
 use Exporter qw();
@@ -50,6 +52,7 @@ use namespace::clean;
 our @EXPORT = qw(
     plugin_namespace
     has_pluggable_object
+    has_pluggable_class
 );
 
 sub import {
@@ -114,19 +117,33 @@ Read more about this at L<MooX::PluginKit/Object Attributes>.
 This function only supports a subset of the arguments that L<Moo/has>
 supports.  They are:
 
-    handles
-    default
     builder
+    default
+    handles
+    init_arg
+    isa
     required
     weak_ref
-    init_arg
 
 =head3 class
 
 Setting this to a class name does two things, 1) it declares the C<isa> on
 the attributes to validate that the final value is an instance of the class
-or a subclass of it, and 2) defaults the L</class_builder> to always return
-this class.
+or a subclass of it, and 2) sets L</default_class> to it.
+
+=head3 default_class
+
+If no class is specified this will be the default class used.  A common idiom
+of using both L</class> and this is:
+
+    has_pluggable_object foo => (
+        class         => 'Foo',
+        default_class => 'Foo::SubClass',
+    );
+
+Meaning, in the above example, that the final object may be any subclass of the
+C<Foo> class, but if no class is specified, it will be constructed from the
+C<Foo::SubClass> class.
 
 =head3 class_arg
 
@@ -158,6 +175,9 @@ Then make the sub:
 
     sub _foo_build_class { my ($self, $args) = @_; ...; return $class }
 
+Note that the class builder will not be called if L</class_arg> if set and
+the user has specified a class argument.
+
 =head3 class_namespace
 
 Set this to allow the class to be relative.  This way if the class starts with
@@ -246,7 +266,7 @@ sub _build_attr_builder {
 
         my $args = $self->$init_name();
         return $args if ref($args) ne 'HASH';
-        $args = $self->$args_builder( $args ) if defined $args_builder;
+        $args = $self->$args_builder({ %$args }) if defined $args_builder;
 
         my $class = $self->$class_builder( $args );
 
@@ -260,31 +280,24 @@ sub _normalize_class_builder {
     my ($name, $consumer_class, %args) = @_;
 
     my $class = delete $args{class};
+    my $default_class = delete $args{default_class};
     my $class_arg = delete $args{class_arg};
     my $class_builder = delete $args{class_builder};
     my $class_namespace = delete $args{class_namespace};
 
+    $default_class = $class if !defined $default_class;
     $class_arg = undef if defined($class_arg) and "$class_arg" eq '0';
     $class_builder = undef if defined($class_builder) and "$class_builder" eq '0';
 
-    croak 'Both class_arg and class_builder cannot be set at the same time'
-        if defined($class_arg) and defined($class_builder);
-
     $class_arg = 'class' if defined($class_arg) and "$class_arg" eq '1';
 
     my $class_builder_sub;
-
-    if (defined $class_arg) {
-        $class_builder = sub{ $_[1]->{$class_arg} };
-    }
-
     if (ref($class_builder) eq 'CODE') {
         $class_builder_sub = $class_builder;
         $class_builder = 1;
     }
-
-    if (defined($class) and !defined($class_builder)) {
-        $class_builder_sub = sub{ $class };
+    elsif (!defined $class_builder) {
+        $class_builder_sub = sub{ undef };
         $class_builder = 1;
     }
 
@@ -300,18 +313,20 @@ sub _normalize_class_builder {
         );
     }
 
-    if (defined $class_namespace) {
-        install_modifier(
-            $consumer_class, 'around',
-            $class_builder => sub{
-                my $orig = shift;
-                my $self = shift;
-                my $class = $self->$orig( @_ );
-                $class = $class_namespace . $class if $class =~ m{^::};
-                return $class;
-            },
-        );
-    }
+    install_modifier(
+        $consumer_class, 'around',
+        $class_builder => sub{
+            my ($orig, $self, $args) = @_;
+
+            my $class = defined($class_arg) ? $args->{$class_arg} : undef;
+            $class = $self->$orig( $args ) if !defined $class;
+            $class = $default_class if !defined $class;
+            return undef if !defined $class;
+
+            $class = $class_namespace . $class if $class =~ m{^::};
+            return $class;
+        },
+    );
 
     return $class_builder;
 }
@@ -345,6 +360,83 @@ sub _normalize_args_builder {
     return $args_builder;
 }
 
+=head2 has_pluggable_class
+
+    has_pluggable_class foo_bar_class => (
+        default => 'Foo::Bar',
+    );
+
+This function acts like L<Moo/has> but adds a bunch of functionality,
+making it easy to refer to a class that gets plugins applied to it
+at run-time.
+
+In the above C<foo_bar_class> example, the user of your class can then specify
+the C<foo_bar_class> argument, if they wish, and the class they pass in will
+have any relevant plugins applied to it.
+
+This function only supports a subset of the arguments that L<Moo/has>
+supports.  They are:
+
+    builder
+    default
+    init_arg
+    isa
+    required
+
+=cut
+
+sub has_pluggable_class {
+    my ($name, %args) = @_;
+    my $consumer_class = (caller())[0];
+    local $Carp::Internal{ (__PACKAGE__) } = 1;
+
+    my $has = get_consumer_moo_has( $consumer_class );
+
+    my $init_name = "_init_$name";
+
+    $has->(
+        $init_name,
+        init_arg => $name,
+        is       => 'ro',
+        isa      => NonEmptySimpleStr,
+        lazy     => 1,
+        (
+            map { $_ => $args{$_} }
+            grep { exists $args{$_} }
+            qw( default builder required init_arg )
+        ),
+    );
+
+    my $isa = $args{isa} || ClassName;
+    $isa = $isa | Undef if !$args{required};
+
+    $has->(
+        $name,
+        init_arg => undef,
+        is       => 'lazy',
+        isa      => $isa,
+        builder => _build_class_attr_builder(
+            $init_name,
+        ),
+    );
+
+    return;
+}
+
+sub _build_class_attr_builder {
+    my ($init_name) = @_;
+
+    return sub{
+        my ($self) = @_;
+
+        my $class = $self->$init_name();
+
+        require_module $class if !$class->can('new');
+
+        return $self->plugin_factory->build_class( $class );
+    };
+}
+
 1;
 __END__
 
