@@ -1,5 +1,5 @@
 package MooX::PluginKit::Plugin;
-$MooX::PluginKit::Plugin::VERSION = '0.02';
+$MooX::PluginKit::Plugin::VERSION = '0.03';
 =head1 NAME
 
 MooX::PluginKit::Plugin - Setup a role as a PluginKit plugin.
@@ -41,8 +41,10 @@ sub import {
 
 =head2 plugin_applies_to
 
-    # Only apply to classes which isa() the supplied class.
+    # Only apply to classes which isa() the supplied class, or
+    # DOES() the supplied role.
     plugin_applies_to 'Some::Class';
+    plugin_applies_to 'Some::Role';
     
     # Only apply to classes which match the regex.
     plugin_applies_to qr/^MyApp::Foo::/;
